#include "tablesupport.ih"

TableSupport::TableSupport()
:
    d_streamPtr(0),
    d_nRows(0),
    d_nColumns(0),
    d_align(0),
    d_tableWidth(0)
{}

